@@ -277,7 +277,8 @@ def setPref(config, comp_name, raw_val) -> bool:
         else:
             print(f"Adding '{raw_val}' to the {pref.name} list")
             cur_vals = [x for x in getattr(config_values, pref.name) if x not in [0, "", b""]]
-            cur_vals.append(val)
+            if val not in cur_vals:
+                cur_vals.append(val)
             getattr(config_values, pref.name)[:] = cur_vals
         return True
 
@@ -1364,6 +1365,7 @@ def common():
                     debugOut=logfile,
                     noProto=args.noproto,
                     noNodes=args.no_nodes,
+                    timeout=args.timeout,
                 )
             elif args.host:
                 try:
@@ -1378,6 +1380,7 @@ def common():
                         debugOut=logfile,
                         noProto=args.noproto,
                         noNodes=args.no_nodes,
+                        timeout=args.timeout,
                     )
                 except Exception as ex:
                     meshtastic.util.our_exit(f"Error connecting to {args.host}:{ex}", 1)
@@ -1388,6 +1391,7 @@ def common():
                         debugOut=logfile,
                         noProto=args.noproto,
                         noNodes=args.no_nodes,
+                        timeout=args.timeout,
                     )
                 except FileNotFoundError:
                     # Handle the case where the serial device is not found
@@ -1425,6 +1429,7 @@ def common():
                             debugOut=logfile,
                             noProto=args.noproto,
                             noNodes=args.no_nodes,
+                            timeout=args.timeout,
                         )
                     except Exception as ex:
                         meshtastic.util.our_exit(
